import setuptools

setuptools.setup(
    name="VerbalRegex",
    version="1.0.0",
    license='MIT',
    author="dongmin",
    author_email="happydm09@naver.com",
    description='정규표현식을 쉽게 쓸 수 있게 합니다. Makes it easy to use regular expressions',
    url="https://github.com/DM-09/Verbal-Regex.py/",
    python_requires='>=3.1',
    packages=setuptools.find_packages(),
    keywords=['Regex', 'VerbalRegex', 'Verbal Regex', 'Regular Expression'],
)